#!/usr/bin/env python
#
# Copyright (C) 2011 W. Trevor King <wking@drexel.edu>
#
# This file is part of unfold_protein.
#
# Unfold_protein is free software: you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation, either
# version 3 of the License, or (at your option) any later version.
#
# Unfold_protein is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with unfold_protein.  If not, see
# <http://www.gnu.org/licenses/>.

"""Run a mechanical protein unfolding experiment."""

import os
import os.path

from calibcant.config import Kelvin as _Kelvin
from unfold_protein import __version__ as version
from unfold_protein.afm import get_afm
from unfold_protein.unfolder import Unfolder
from unfold_protein.scan import UnfoldScanner
import unfold_protein.config as _config


if __name__ == '__main__':
    from argparse import ArgumentParser

    parser = ArgumentParser(
        description='Play a pure tone', version=version)
    parser.add_argument(
        '-s', '--song',
        help='Path to a song to play when the experiment is complete')

    args = parser.parse_args()

    unfold_config = _config.UnfoldCycleConfig()
    unfold_config['temperature'] = _config.TemperatureConfig()
    unfold_config['temperature']['units'] = _Kelvin
    unfold_config['approach'] = _config.ApproachConfig()
    unfold_config['unfold'] = _config.UnfoldConfig()
    unfold_config['save'] = _config.SaveConfig()
    scan_config = _config.ScanConfig()
    scan_config['velocity'] = _config.VelocityScanConfig()
    scan_config['position'] = _config.PositionScanConfig()

    afm,comedi_device = get_afm(with_temperature=False)
    unfolder = Unfolder(config=unfold_config, afm=afm)
    scanner = UnfoldScanner(config=scan_config, unfolder=unfolder)
    try:
        scanner.run()
    finally:
        scanner.move_far_from_surface()
        comedi_device.close()
        if args.song:
            song = os.path.abspath(os.path.expanduser(args.song))
            os.system("aplay '%s'" % song)
